==> nextcloud-21.0.4.tgz: nextcloud/apps/user_status/l10n/af.js <==
OC.L10N.register(
    "user_status",
    {
    "Recent statuses" : "Onlangse statusse",
    "In a meeting" : "In ’n vergadering",
    "Commuting" : "In die verkeer",
    "Out sick" : "Siek tuis",
    "Vacationing" : "Met vakansie",
    "Working remotely" : "Werk in die veld",
    "User status" : "Gebruikerstatus",
    "Clear status message after" : "Wis statusboodskap na",
    "What's your status?" : "Wat is u status",
    "Set status" : "Stel status",
    "Online status" : "Aanlyn status",
    "Status message" : "Statusboodskap",
    "Clear status message" : "Wis statusboodskap",
    "Set status message" : "Stel statusboodskap",
    "There was an error saving the status" : "Daar was ’n fout toe status bewaar is",
    "There was an error clearing the status" : "Daar was ’n fout toe die status gewis is",
    "No recent status changes" : "Geen onlangse statusverandering nie",
    "Away" : "Weg",
    "Do not disturb" : "Moenie pla nie",
    "{status}, {timestamp}" : "{status}, {timestamp}",
    "Don't clear" : "Moenie wis nie",
    "Today" : "Vandag",
    "This week" : "Vandeesweek",
    "Online" : "Aanlyn",
    "Invisible" : "Onsigbaar",
    "Offline" : "Vanlyn",
    "There was an error saving the new status" : "Daar was ’n fout toe nuwe status bewaar is",
    "30 minutes" : "30 minute",
    "1 hour" : "1 uur",
    "4 hours" : "4 uur",
    "Mute all notifications" : "Demp alle kennisgewings",
    "Appear offline" : "Toon as vanlyn",
    "Clear status after" : "Wis status na"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-21.0.8p0.tgz: nextcloud/apps/user_status/l10n/af.js <==
OC.L10N.register(
    "user_status",
    {
    "Recent statuses" : "Onlangse statusse",
    "In a meeting" : "In ’n vergadering",
    "Commuting" : "In die verkeer",
    "Out sick" : "Siek tuis",
    "Vacationing" : "Met vakansie",
    "Working remotely" : "Werk in die veld",
    "User status" : "Gebruikerstatus",
    "Clear status message after" : "Wis statusboodskap na",
    "Set status" : "Stel status",
    "Online status" : "Aanlyn status",
    "Status message" : "Statusboodskap",
    "Clear status message" : "Wis statusboodskap",
    "Set status message" : "Stel statusboodskap",
    "There was an error saving the status" : "Daar was ’n fout toe status bewaar is",
    "There was an error clearing the status" : "Daar was ’n fout toe die status gewis is",
    "No recent status changes" : "Geen onlangse statusverandering nie",
    "Away" : "Weg",
    "Do not disturb" : "Moenie pla nie",
    "{status}, {timestamp}" : "{status}, {timestamp}",
    "Don't clear" : "Moenie wis nie",
    "Today" : "Vandag",
    "This week" : "Vandeesweek",
    "Online" : "Aanlyn",
    "Invisible" : "Onsigbaar",
    "Offline" : "Vanlyn",
    "There was an error saving the new status" : "Daar was ’n fout toe nuwe status bewaar is",
    "30 minutes" : "30 minute",
    "1 hour" : "1 uur",
    "4 hours" : "4 uur",
    "Mute all notifications" : "Demp alle kennisgewings",
    "Appear offline" : "Toon as vanlyn",
    "Clear status after" : "Wis status na",
    "What's your status?" : "Wat is u status"
},
"nplurals=2; plural=(n != 1);");
